@@ -16,8 +16,8 @@ running Editra.
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__svnid__ = "$Id: Editra.py 61778 2009-08-29 03:58:16Z CJP $"
-__revision__ = "$Revision: 61778 $"
+__svnid__ = "$Id: Editra.py 62452 2009-10-18 19:22:00Z CJP $"
+__revision__ = "$Revision: 62452 $"
 
 #--------------------------------------------------------------------------#
 # Dependancies
@@ -148,6 +148,15 @@ class Editra(wx.App, events.AppEventHandlerMixin):
             self._log("[app][info] Registering Editra's ArtProvider")
             wx.ArtProvider.PushProvider(ed_art.EditraArt())
 
+        # Check if libenchant has been loaded or need to be
+        import extern.stcspellcheck as stcspellcheck
+        checker = stcspellcheck.STCSpellCheck
+        if not checker.isEnchantOk():
+            spref = profiler.Profile_Get('SPELLCHECK', default=dict())
+            libpath = spref.get('epath', u'')
+            checker.reloadEnchant(libpath)
+            # TODO: log if load fails here
+
     def AddMessageCatalog(self, name, path):
         """Add a catalog lookup path to the app
         @param name: name of catalog (i.e 'projects')
