@@ -15,8 +15,8 @@ syntax highlighting of all supported filetypes.
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__svnid__ = "$Id: ed_basestc.py 61600 2009-08-04 16:34:20Z CJP $"
-__revision__ = "$Revision: 61600 $"
+__svnid__ = "$Id: ed_basestc.py 62523 2009-10-31 21:03:19Z CJP $"
+__revision__ = "$Revision: 62523 $"
 
 #-----------------------------------------------------------------------------#
 # Imports
@@ -32,7 +32,8 @@ import ebmlib
 import ed_msg
 import ed_txt
 from syntax import syntax
-from autocomp import autocomp
+from syntax import synglob
+import autocomp
 from extern import vertedit
 from profiler import Profile_Get
 
@@ -51,7 +52,7 @@ CTRL_SHIFT = wx.stc.STC_SCMOD_CTRL|wx.stc.STC_SCMOD_SHIFT
 
 class EditraBaseStc(wx.stc.StyledTextCtrl, ed_style.StyleMgr):
     """Base StyledTextCtrl that provides all the base code editing
-    functionatlity.
+    functionality.
 
     """
     ED_STC_MASK_MARKERS = ~wx.stc.STC_MASK_FOLDERS
@@ -71,6 +72,7 @@ class EditraBaseStc(wx.stc.StyledTextCtrl, ed_style.StyleMgr):
                           lang_id=0)        # Language ID from syntax module
 
         self.vert_edit = vertedit.VertEdit(self)
+        self._line_num = True # Show line numbers
 
         # Set Up Margins
         ## Outer Left Margin Bookmarks
@@ -132,7 +134,7 @@ class EditraBaseStc(wx.stc.StyledTextCtrl, ed_style.StyleMgr):
             self.LineDown()
 
     def AutoIndent(self):
-        """Indent from the current postion to match the indentation
+        """Indent from the current position to match the indentation
         of the previous line.
         @postcondition: proper type of white space is added from current pos
                         to match that of indentation in above line
@@ -251,7 +253,7 @@ class EditraBaseStc(wx.stc.StyledTextCtrl, ed_style.StyleMgr):
     def Comment(self, start, end, uncomment=False):
         """(Un)Comments a line or a selected block of text
         in a document.
-        @param start: begining line (int)
+        @param start: beginning line (int)
         @param end: end line (int)
         @keyword uncomment: uncomment selection
 
@@ -317,19 +319,16 @@ class EditraBaseStc(wx.stc.StyledTextCtrl, ed_style.StyleMgr):
 #        self.AutoCompSetFillUps(self._code['compsvc'].GetAutoCompFillups())
 
     def ConfigureLexer(self, file_ext):
-        """Sets Lexer and Lexer Keywords for the specifed file extension
+        """Sets Lexer and Lexer Keywords for the specified file extension
         @param file_ext: a file extension to configure the lexer from
 
         """
-        syn_data = self._code['synmgr'].SyntaxData(file_ext)
+        syn_data = self._code['synmgr'].GetSyntaxData(file_ext)
 
         # Set the ID of the selected lexer
-        try:
-            self._code['lang_id'] = syn_data[syntax.LANGUAGE]
-        except KeyError:
-            self._code['lang_id'] = 0
+        self._code['lang_id'] = syn_data.LangId
 
-        lexer = syn_data[syntax.LEXER]
+        lexer = syn_data.Lexer
         # Check for special cases
         # TODO: add fetch method to check if container lexer requires extra
         #       style bytes beyond the default 5.
@@ -344,46 +343,21 @@ class EditraBaseStc(wx.stc.StyledTextCtrl, ed_style.StyleMgr):
         else:
             self.SetStyleBits(5)
 
-        try:
-            keywords = syn_data[syntax.KEYWORDS]
-        except KeyError:
-            keywords = []
-
-        try:
-            synspec = syn_data[syntax.SYNSPEC]
-        except KeyError:
-            synspec = []
-
-        try:
-            props = syn_data[syntax.PROPERTIES]
-        except KeyError:
-            props = []
-
-        try:
-            comment = syn_data[syntax.COMMENT]
-        except KeyError:
-            comment = []
-
-        try:
-            clexer = syn_data[syntax.CLEXER]
-        except KeyError:
-            clexer = None
-
-        try:
-            indenter = syn_data[syntax.INDENTER]
-        except KeyError:
-            indenter = None
-
         # Set Lexer
         self.SetLexer(lexer)
         # Set Keywords
-        self.SetKeyWords(keywords)
+        self.SetKeyWords(syn_data.Keywords)
         # Set Lexer/Syntax Specifications
-        self.SetSyntax(synspec)
+        self.SetSyntax(syn_data.SyntaxSpec)
         # Set Extra Properties
-        self.SetProperties(props)
+        self.SetProperties(syn_data.Properties)
         # Set Comment Pattern
-        self._code['comment'] = comment
+        self._code['comment'] = syn_data.CommentPattern
+
+        # Get Extension Features
+        clexer = syn_data.GetFeature(synglob.FEATURE_STYLETEXT)
+        indenter = syn_data.GetFeature(synglob.FEATURE_AUTOINDENT)
+
         # Set the Container Lexer Method
         self._code['clexer'] = clexer
         # Auto-indenter function
@@ -442,13 +416,24 @@ class EditraBaseStc(wx.stc.StyledTextCtrl, ed_style.StyleMgr):
             self.SetZoom(0)
         return self.GetZoom()
 
+    def EnableLineNumbers(self, enable=True):
+        """Enable/Disable line number margin
+        @keyword enable: bool
+
+        """
+        if enable:
+            self.SetMarginWidth(NUM_MARGIN, 30)
+        else:
+            self.SetMarginWidth(NUM_MARGIN, 0)
+        self._line_num = enable
+
     def FindChar(self, char, repeat=1, reverse=False, extra_offset=0):
         """Find the position of the next (ith) 'char' character
         on the current line and move caret to it
 
         @note: used by vim motions for finding a character on a line (f,F,t,T)
         @param char: the character to be found
-        @keyword repeat: how many times to repeat the serach
+        @keyword repeat: how many times to repeat the search
         @keyword reverse: whether to search backwards
         @keyword extra_offset: extra offset to be applied to the movement
 
@@ -512,7 +497,7 @@ class EditraBaseStc(wx.stc.StyledTextCtrl, ed_style.StyleMgr):
         self.Colourise(0, -1)
 
     def FireModified(self):
-        """Fire a modifed event"""
+        """Fire a modified event"""
         self.OnChanged(wx.stc.StyledTextEvent(wx.stc.wxEVT_STC_CHANGE,
                                               self.GetId()))
 
@@ -523,7 +508,7 @@ class EditraBaseStc(wx.stc.StyledTextCtrl, ed_style.StyleMgr):
         @todo: fillups are currently disabled. See note in Configure.
 
         """
-        # NOTE: the column position retuned by GetCurLine is not correct
+        # NOTE: the column position returned by GetCurLine is not correct
         #       for multibyte characters.
         line, col = self.GetCurLine()
         col = self.GetColumn(self.GetCurrentPos())
@@ -609,7 +594,7 @@ class EditraBaseStc(wx.stc.StyledTextCtrl, ed_style.StyleMgr):
         return self._code['keywords']
 
     def GetLangId(self):
-        """Returns the language identifer of this control
+        """Returns the language identifier of this control
         @return: language identifier of document
         @rtype: int
 
@@ -629,6 +614,17 @@ class EditraBaseStc(wx.stc.StyledTextCtrl, ed_style.StyleMgr):
 
     GetRange = wx.stc.StyledTextCtrl.GetTextRange
 
+    def GetWordFromPosition(self, pos):
+        """Get the word at the given position
+        @param pos: int
+        @return: (string, int_start, int_end)
+
+        """
+        end = self.WordEndPosition(pos, True)
+        start = self.WordStartPosition(pos, True)
+        word = self.GetTextRange(start, end)
+        return (word, start, end)
+
     def IsColumnMode(self):
         """Is the buffer in column edit mode
         @return: bool
@@ -673,6 +669,7 @@ class EditraBaseStc(wx.stc.StyledTextCtrl, ed_style.StyleMgr):
         if txt is not None:
             if self.file.IsRawBytes() and not ebmlib.IsUnicode(txt):
                 self.AddStyledText(txt)
+                self.SetReadOnly(True) # Don't allow editing of raw bytes
             else:
                 self.SetText(txt)
         else:
@@ -703,19 +700,20 @@ class EditraBaseStc(wx.stc.StyledTextCtrl, ed_style.StyleMgr):
         @type evt: wx.stc.StyledTextEvent
 
         """
-        # Adjust line number margin width to expand as needed when line
-        # number width over fills the area.
-        lines = self.GetLineCount()
-        mwidth = self.GetTextExtent(str(lines))[0]
+        if self._line_num:
+            # Adjust line number margin width to expand as needed when line
+            # number width over fills the area.
+            lines = self.GetLineCount()
+            mwidth = self.GetTextExtent(str(lines))[0]
 
-        if wx.Platform == '__WXMAC__':
-            adj = 2
-        else:
-            adj = 8
+            if wx.Platform == '__WXMAC__':
+                adj = 2
+            else:
+                adj = 8
 
-        nwidth = max(15, mwidth + adj)
-        if self.GetMarginWidth(NUM_MARGIN) != nwidth:
-            self.SetMarginWidth(NUM_MARGIN, nwidth)
+            nwidth = max(15, mwidth + adj)
+            if self.GetMarginWidth(NUM_MARGIN) != nwidth:
+                self.SetMarginWidth(NUM_MARGIN, nwidth)
 
         wx.PostEvent(self.GetParent(), evt)
         ed_msg.PostMessage(ed_msg.EDMSG_UI_STC_CHANGED)
@@ -809,8 +807,6 @@ class EditraBaseStc(wx.stc.StyledTextCtrl, ed_style.StyleMgr):
     def SetKeyWords(self, kw_lst):
         """Sets the keywords from a list of keyword sets
         @param kw_lst: [ (KWLVL, "KEWORDS"), (KWLVL2, "KEYWORDS2"), ect...]
-        @todo: look into if the uniquifying of the list has a more optimal
-               solution.
 
         """
         # Parse Keyword Settings List simply ignoring bad values and badly
@@ -829,8 +825,8 @@ class EditraBaseStc(wx.stc.StyledTextCtrl, ed_style.StyleMgr):
                     super(EditraBaseStc, self).SetKeyWords(keyw[0], keyw[1])
 
         kwlist = kwlist.split()         # Split into a list of words
-        kwlist = list(set(kwlist))      # Uniqueify the list
-        kwlist.sort()                   # Sort into alphbetical order
+        kwlist = list(set(kwlist))      # Remove duplicates from the list
+        kwlist.sort()                   # Sort into alphabetical order
 
         # Can't have ? in scintilla autocomp list unless specifying an image
         if '?' in kwlist:
@@ -928,7 +924,7 @@ class EditraBaseStc(wx.stc.StyledTextCtrl, ed_style.StyleMgr):
             if end > start and self.GetColumn(sel[1]) == 0:
                 end = end - 1
 
-            # Analyze the seleted line(s)
+            # Analyze the selected line(s)
             comment = 0
             for line in range(start, end+1):
                 txt = self.GetLine(line)
@@ -953,9 +949,9 @@ class EditraBaseStc(wx.stc.StyledTextCtrl, ed_style.StyleMgr):
         """
         if (switch is None and \
             not self.GetMarginWidth(NUM_MARGIN)) or switch:
-            self.SetMarginWidth(NUM_MARGIN, 30)
+            self.EnableLineNumbers(True)
         else:
-            self.SetMarginWidth(NUM_MARGIN, 0)
+            self.EnableLineNumbers(False)
 
     @property
     def VertEdit(self):
