@@ -15,8 +15,8 @@ main Ui component of the editor that contains all the other components.
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__svnid__ = "$Id: ed_main.py 61605 2009-08-05 13:41:45Z CJP $"
-__revision__ = "$Revision: 61605 $"
+__svnid__ = "$Id: ed_main.py 62144 2009-09-26 14:28:20Z CJP $"
+__revision__ = "$Revision: 62144 $"
 
 #--------------------------------------------------------------------------#
 # Dependancies
@@ -36,6 +36,7 @@ import ed_event
 import ed_msg
 import ed_menu
 import ed_print
+import ed_shelf
 import ed_statbar
 import ed_mdlg
 import prefdlg
@@ -286,9 +287,12 @@ class MainWindow(wx.Frame, viewmgr.PerspectiveManager):
         addons.Init(self)
         self._handlers['menu'].extend(addons.GetEventHandlers())
         self._handlers['ui'].extend(addons.GetEventHandlers(ui_evt=True))
-        self._shelf = iface.Shelf(plgmgr)
-        self._shelf.Init(self)
-        self._handlers['ui'].extend(self._shelf.GetUiHandlers())
+        shelf = ed_shelf.Shelf(plgmgr)
+        shelf.Init(self)
+        self._handlers['ui'].extend(shelf.GetUiHandlers())
+        self._shelf = ed_shelf.Shelf.delegate
+        ed_shelf.Shelf.delegate = None
+
         self.LOG("[ed_main][info] Loading Generator plugins")
         generator.Generator(plgmgr).InstallMenu(menbar.GetMenuByName("tools"))
 
@@ -1467,6 +1471,16 @@ class MainWindow(wx.Frame, viewmgr.PerspectiveManager):
 
         return result
 
+    def PushStatusText(self, txt, field):
+        """Override so that our custom status bar's method gets called
+        do to these wxFrame methods not being exposed as virtuals.
+
+        """
+        sb = self.GetStatusBar()
+        sb.PushStatusText(txt, field)
+
+    SetStatusText = PushStatusText
+
     def SetTitle(self, title=u''):
         """Sets the windows title
         @param title: The text to tag on to the default frame title
