@@ -15,8 +15,8 @@ text documents and files.
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__svnid__ = "$Id: ed_search.py 61781 2009-08-29 15:45:54Z CJP $"
-__revision__ = "$Revision: 61781 $"
+__svnid__ = "$Id: ed_search.py 62512 2009-10-31 00:34:33Z CJP $"
+__revision__ = "$Revision: 62512 $"
 
 #--------------------------------------------------------------------------#
 # Imports
@@ -132,13 +132,13 @@ class SearchController(object):
             self._finddlg.Destroy()
 
     def _CreateNewDialog(self, e_id):
-        """Create and set the controlers find dialog
+        """Create and set the controllers find dialog
         @param e_id: Dialog Type Id
 
         """
         # TODO: find out why parent is not a Window in some cases...
         if not isinstance(self._parent, wx.Window):
-            parent = wx.GetApp().ActiveWindow()
+            parent = wx.GetApp().GetActiveWindow()
         else:
             parent = self._parent
 
@@ -245,7 +245,7 @@ class SearchController(object):
         return rtext
 
     def GetData(self):
-        """Get the contollers FindReplaceData
+        """Get the controllers FindReplaceData
         @return: wx.FindReplaceData
 
         """
@@ -262,7 +262,7 @@ class SearchController(object):
         """Returns the position value of the last found search item
         if the last search resulted in nothing being found then the
         return value will -1.
-        @return: position of last search opperation
+        @return: position of last search operation
         @rtype: int
 
         """
@@ -324,6 +324,10 @@ class SearchController(object):
             flags = data.GetFlags()
             if not findnext and evt.GetId() == ed_glob.ID_FIND_PREVIOUS:
                 flags |= eclib.AFR_UP
+            elif eclib.AFR_UP & flags:
+                # Not a find previous request so make sure that
+                # the search up flag is cleared.
+                flags ^= eclib.AFR_UP
 
             evt = eclib.FindEvent(eclib.edEVT_FIND_NEXT, flags=flags)
             evt.SetFindString(data.GetFindString())
@@ -347,7 +351,7 @@ class SearchController(object):
                           style=wx.OK|wx.CENTER|wx.ICON_ERROR)
             return
 
-        # XXX: may be inefficent to copy whole buffer each time for files
+        # XXX: may be inefficient to copy whole buffer each time for files
         #      that are large.
         self._engine.SetSearchPool(stc.GetTextRaw())
 
@@ -487,8 +491,8 @@ class SearchController(object):
             evt.Skip()
 
     def OnFindClose(self, evt):
-        """Destroy Find Dialog After Cancel is clicked in it
-        @param evt: event that called this handler
+        """Process storing search dialog state when it is closed
+        @param evt: findlg.EVT_FIND_CLOSE
 
         """
         if self._finddlg is not None:
@@ -507,6 +511,7 @@ class SearchController(object):
             Profile_Set('SEARCH_LOC', choices)
             Profile_Set('SEARCH_FILTER', self._filters)
         evt.Skip()
+        self._parent.SetFocus()
 
     def OnOptionChanged(self, evt):
         """Handle when the find options are changed in the dialog"""
@@ -856,7 +861,7 @@ class EdSearchCtrl(wx.SearchCtrl):
         else:
             # ?wxBUG? cant set text back to black after changing color
             # But setting it to this almost black color works. Most likely its
-            # due to bit masking but I havent looked at the source so I am not
+            # due to bit masking but I haven't looked at the source so I am not
             # sure
             if self._txtctrl is None:
                 self.SetForegroundColour(wx.ColourRGB(0 | 1 | 0))
