@@ -15,8 +15,8 @@ messages from ed_msg to display progress of different actions.
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__svnid__ = "$Id: ed_statbar.py 60987 2009-06-10 17:32:23Z CJP $"
-__revision__ = "$Revision: 60987 $"
+__svnid__ = "$Id: ed_statbar.py 62460 2009-10-21 03:13:18Z CJP $"
+__revision__ = "$Revision: 62460 $"
 
 #--------------------------------------------------------------------------#
 # Imports
@@ -27,7 +27,7 @@ import wx.stc
 import ed_glob
 import util
 import ed_msg
-from syntax.syntax import GetFtypeDisplayName
+from syntax.synglob import GetDescriptionFromId
 from eclib.pstatbar import ProgressStatusBar
 from extern.decorlib import anythread
 
@@ -44,13 +44,14 @@ class EdStatBar(ProgressStatusBar):
     """
     ID_CLEANUP_TIMER = wx.NewId()
     def __init__(self, parent):
-        ProgressStatusBar.__init__(self, parent, style=wx.ST_SIZEGRIP)
+        super(EdStatBar, self).__init__(parent, style=wx.ST_SIZEGRIP)
 
         # Attributes
         self._pid = parent.GetId() # Save parents id for filtering msgs
         self._widths = list()
         self._cleanup_timer = wx.Timer(self, EdStatBar.ID_CLEANUP_TIMER)
         self._eolmenu = wx.Menu()
+        self._log = wx.GetApp().GetLog()
 
         # Setup
         self.SetFieldsCount(6) # Info, vi stuff, line/progress
@@ -82,7 +83,7 @@ class EdStatBar(ProgressStatusBar):
         ed_msg.Unsubscribe(self.OnProgress)
         ed_msg.Unsubscribe(self.OnUpdateText)
         ed_msg.Unsubscribe(self.OnUpdateDoc)
-        ProgressStatusBar.__del__(self)
+        super(EdStatBar, self).__del__()
 
     def __SetStatusText(self, txt, field):
         """Safe method to use for setting status text with CallAfter.
@@ -91,19 +92,26 @@ class EdStatBar(ProgressStatusBar):
 
         """
         try:
-            ProgressStatusBar.SetStatusText(self, txt, field)
+            super(EdStatBar, self).SetStatusText(txt, field)
             self.AdjustFieldWidths()
 
-            if field == ed_glob.SB_INFO:
+            if field == ed_glob.SB_INFO and txt != u'':
                 # Start the expiration countdown
                 if self._cleanup_timer.IsRunning():
                     self._cleanup_timer.Stop()
                 self._cleanup_timer.Start(10000, True)
-        except wx.PyDeadObjectError:
+        except wx.PyDeadObjectError, wx.PyAssertionError:
+            # Getting some odd assertion errors on wxMac so just trap
+            # and ignore them for now
+            # glyphCount == (text.length()+1)" failed at graphics.cpp(2048)
+            # in GetPartialTextExtents()
             pass
+        except TypeError, err:
+            self._log("[estatbar][err] Bad status message: %s" % str(txt))
+            self._log("[estatbar][err] %s" % err)
 
     def AdjustFieldWidths(self):
-        """Adust each field width of status bar basing on the field text
+        """Adjust each field width of status bar basing on the field text
         @return: None
 
         """
@@ -224,7 +232,7 @@ class EdStatBar(ProgressStatusBar):
             wx.CallAfter(self.__SetStatusText, txt, field)
 
     def OnUpdateText(self, msg):
-        """Update the status bar text based on the recieved message
+        """Update the status bar text based on the received message
         @param msg: Message Object
 
         """
@@ -263,7 +271,7 @@ class EdStatBar(ProgressStatusBar):
             wx.CallAfter(self.__SetStatusText, doc.GetEncoding(),
                          ed_glob.SB_ENCODING)
             wx.CallAfter(self.__SetStatusText,
-                         GetFtypeDisplayName(cbuff.GetLangId()),
+                         GetDescriptionFromId(cbuff.GetLangId()),
                          ed_glob.SB_LEXER)
 
             eol = { wx.stc.STC_EOL_CR : u"CR",
