@@ -20,8 +20,8 @@ happen during run time.
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__svnid__ = "$Id: profiler.py 61781 2009-08-29 15:45:54Z CJP $"
-__revision__ = "$Revision: 61781 $"
+__svnid__ = "$Id: profiler.py 62162 2009-09-26 21:59:23Z CJP $"
+__revision__ = "$Revision: 62162 $"
 
 #--------------------------------------------------------------------------#
 # Imports
@@ -34,6 +34,7 @@ import wx
 from ed_glob import CONFIG, PROG_NAME, VERSION, PRINT_BLACK_WHITE, EOL_MODE_LF
 import util
 import dev_tool
+import ed_msg
 
 _ = wx.GetTranslation
 #--------------------------------------------------------------------------#
@@ -90,6 +91,9 @@ _DEFAULTS = {
            'SHOW_EOL'   : False,            # Show EOL markers
            'SHOW_LN'    : True,             # Show Line Numbers
            'SHOW_WS'    : False,            # Show whitespace markers
+           'SPELLCHECK' : dict(auto=False,
+                               dict='en_US',
+                               epath=None), # Spell checking preferences
            'STATBAR'    : True,             # Show Status Bar
            'SYNTAX'     : True,             # Use Syntax Highlighting
            'SYNTHEME'   : 'Default',        # Syntax Highlight color scheme
@@ -224,6 +228,9 @@ class Profile(dict):
         else:
             self.__setitem__(index, _FromObject(val, fmt))
 
+        # Notify all clients with the configuration change message
+        ed_msg.PostMessage(ed_msg.EDMSG_PROFILE_CHANGE + (index,), val) 
+
     def Write(self, path):
         """Write the dataset of this profile as a pickle
         @param path: path to where to write the pickle
