@@ -12,15 +12,17 @@
 """
 FILE: synextreg.py
 LANGUAGE: Python
-@summary: This module defines all supported language/filetype indentifiers and
+@summary: This module defines all supported language/filetype identifiers and
           an extension register for mapping file extensions to filetypes.
 @see: synglob.py for more details on how this data is used
 
+@note: Don't use this module directly for internal use only
+
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__svnid__ = "$Id: synextreg.py 60800 2009-05-30 01:29:53Z CJP $"
-__revision__ = "$Revision: 60800 $"
+__svnid__ = "$Id: synextreg.py 62513 2009-10-31 04:48:39Z CJP $"
+__revision__ = "$Revision: 62513 $"
 
 #-----------------------------------------------------------------------------#
 import os
@@ -102,6 +104,8 @@ ID_LANG_PIKE = _NewId()
 LANG_PIKE = u'Pike'
 ID_LANG_SQUIRREL = _NewId()
 LANG_SQUIRREL = u'Squirrel'
+ID_LANG_STATA = _NewId()
+LANG_STATA = u'Stata'
 ID_LANG_VALA = _NewId()
 LANG_VALA = u'Vala'
 
@@ -281,14 +285,11 @@ ID_LANG_R = _NewId()
 LANG_R = u'R'
 ID_LANG_S = _NewId()
 LANG_S = u'S'
-
 ID_LANG_GROOVY = _NewId()
 LANG_GROOVY = u'Groovy'
-
 ID_LANG_XTEXT = _NewId()
 LANG_XTEXT = u'Xtext'
 
-
 #---- End Language Identifier Keys ----#
 
 # Default extensions to file type mapping
@@ -353,7 +354,8 @@ EXT_MAP = {
            'ini inf reg url cfg cnf' : LANG_PROPS,
            'ai ps'              : LANG_PS,
            'py pyw python'      : LANG_PYTHON,
-           'r'                  : LANG_R,        
+           'r'                  : LANG_R,
+           'do ado'             : LANG_STATA,
            'rake rb rbw rbx gemspec' : LANG_RUBY,
            's'                  : LANG_S,
            'scm smd ss'         : LANG_SCHEME,
@@ -456,7 +458,7 @@ class ExtensionRegister(dict):
         else:
             assoc = list(set(exts))
         assoc.sort()
-        self.__setitem__(ftype, assoc)
+        super(ExtensionRegister, self).__setitem__(ftype, assoc)
 
     def Disassociate(self, ftype, ext):
         """Disassociate a file type with a given extension or space
@@ -470,8 +472,8 @@ class ExtensionRegister(dict):
         if assoc:
             for item in to_drop:
                 if item in assoc:
-                    assoc.pop([assoc.index(item)])
-            self.__setitem__(ftype, assoc)
+                    assoc.remove(item)
+            super(ExtensionRegister, self).__setitem__(ftype, assoc)
         else:
             pass
 
@@ -508,7 +510,7 @@ class ExtensionRegister(dict):
             self.__setitem__(EXT_MAP[key], key.split())
 
     def LoadFromConfig(self, config):
-        """Load the extention register with values from a config file
+        """Load the extension register with values from a config file
         @param config: path to config file to load settings from
 
         """
@@ -531,11 +533,12 @@ class ExtensionRegister(dict):
         """Like Associate but overrides any current settings instead of
         just adding to them.
         @param ftype: File type description string
-        @param ext: file extension to set
+        @param ext: space separated list of file extensions to set
 
         """
         self.__setitem__(ftype, list(set(ext.split())))
 
+#-----------------------------------------------------------------------------#
 
 def GetFileExtensions():
     """Gets a sorted list of all file extensions the editor is configured
@@ -546,4 +549,17 @@ def GetFileExtensions():
     extreg = ExtensionRegister()
     return extreg.GetAllExtensions()
 
+def RegisterNewLangId(langId, langName):
+    """Register a new language identifier
+    @param langId: "ID_LANG_FOO"
+    @param langName: "Foo"
+    @return: int
+
+    """
+    gdict = globals()
+    if langId not in gdict:
+        gdict[langId] = _NewId()
+        gdict[langId[3:]] = langName
+    return gdict[langId]
+
 #-----------------------------------------------------------------------------#
